from setuptools import setup, find_packages

setup(
    name='email_templates',
    version='0.2.2',
    author='',
    author_email='',
    packages=find_packages(),
    url='',
    description='Django email templates',
    long_description='',
    install_requires=[],
    dependency_links=[],
    include_package_data=True,
    zip_safe=False,
    platforms=['any'],
)
